import argparse
import setuptools
from .modules import SecretM


def get_args():
    args = argparse.ArgumentParser()

    args.add_argument('-n', action='store_false',
                      help='Don\'t generate a colorscheme or set terminal colors')

    args.add_argument('-v', action='store_true',
                      help='Print version')
    args.add_argument(
        'platform',
        help='Give the platform name as mentioned in our documentation.',
    )

    args.add_argument(
        '--uid',
        help='Give the Unique Identification of the target user for the given platform. \nRefer to documentation for more details.',
        required=True
    )

    args.add_argument(
        '--repeat',
        help='Number of times to repeat the message sending.',
        default=1,
        type=int
    )

    args.add_argument(
        '--custom_text',
        help='Give a list possible text messages to send. Keep each message within quotation.',
        nargs='+'
    )

    return args.parse_args()


def main():
    args = get_args()
    platform = args.platform
    # print(args)
    messengers = {
        'secretm': SecretM
    }
    if platform not in messengers:
        print('The requested platform is not supported yet. Please raise an issue in GitHub to request addition.')
        return
    messenger = messengers[platform](
        uid=args.uid,
        messages={'custom_text': args.custom_text} if args.custom_text else None
    )
    messenger.post(n=args.repeat)


if __name__ == '__main__':
    main()



import requests
import random
import json
import os
from concurrent.futures import ThreadPoolExecutor


class SecretM:
    def __init__(self, uid=None, messages=None):
        self._base_url = 'https://secretm.me'
        self._page = 'message_h.php'
        self.uid = uid
        self.messages = messages
        self.load_messages()

    def load_messages(self) -> None:
        if self.messages is None:
            with open(os.path.join('AnonAutomator_arin17', 'resources', 'messages.json'), 'r') as fp:
                self.messages = json.load(fp)
        return

    def get_full_url(self) -> str:
        return '/'.join((self._base_url, self._page))

    def get_message(self) -> str:
        key = random.choice(tuple(self.messages.keys()))
        return random.choice(self.messages[key])

    def prepare_payload(self) -> dict:
        res = {
            'name': str(self.uid),
            'ans1': self.get_message(),
            'agree': 'on'
        }
        return res

    def _post(self, idx: int) -> None:
        payload = self.prepare_payload()
        res = requests.post(url=self.get_full_url(), data=payload)
        print("For message number {}: Status code - {}".format(idx, res.status_code))

    def post(self, n: int = 1):
        with ThreadPoolExecutor() as executor:
            executor.map(self._post, range(1, n + 1))
